function [xh,uh]=bvp(a,b,N,mu,eta,sigma,bvpfun,...
                    ua,ub,varargin)
%BVP rsout des problmes aux limites 1D.
%  [XH,UH]=BVP(A,B,N,MU,ETA,SIGMA,BVPFUN,UA,UB)
%  rsout avec la mthode des diffrences finies
%  centres le problme aux limites
%     -MU*D(DU/DX)/DX+ETA*DU/DX+SIGMA*U=BVPFUN
%  sur l'intervalle ]A,B[ avec les conditions aux
%  limites U(A)=UA et U(B)=UB. BVPFUN peut tre une
%  fonction inline, une fonction anonyme ou dfinie
%  par  M-file.
%  [XH,UH]=BVP(A,B,N,MU,ETA,SIGMA,BVPFUN,UA,UB,...
%  P1,P2,...) passe les paramtres supplmentaires
%  P1, P2, ...  la fonction BVPFUN.
%  XH contient les noeuds de discrtisation,
%  y compris les noeuds du bord.
%  UH contient la solution numrique.
h = (b-a)/(N+1);
xh = (linspace(a,b,N+2))';
hm = mu/h^2;
hd = eta/(2*h);
e =ones(N,1);
A = spdiags([-hm*e-hd (2*hm+sigma)*e -hm*e+hd],...
    -1:1, N, N);
xi = xh(2:end-1);
f =feval(bvpfun,xi,varargin{:});
f(1) =  f(1)+ua*(hm+hd);
f(end) = f(end)+ub*(hm-hd);
uh = A\f;
uh=[ua; uh; ub];
return
