function [t,u]=feuler(odefun,tspan,y0,Nh,varargin)
%FEULER Rsout une quation diffrentielle avec la
%  mthode d'Euler explicite.
%  [T,Y]=FEULER(ODEFUN,TSPAN,Y0,NH) avec TSPAN=[T0,TF]
%  intgre le systme d'quations diffrentielles
%  y'=f(t,y) du temps T0 au temps TF avec la condition
%  initiale Y0 en utilisant la mthode d'Euler
%  explicite sur une grille de NH intervalles
%  quidistribus. La fonction ODEFUN(T,Y) doit
%  retourner un vecteur, correspondant  f(t,y),
%  de mme dimension que Y.
%  Chaque ligne de la solution Y correspond
%   un temps du vecteur colonne T.
%  [T,Y] = FEULER(ODEFUN,TSPAN,Y0,NH,P1,P2,...) passe
%  les paramtres supplmentaires P1,P2,..  la
%  fonction  ODEFUN de la maniere suivante:
%  ODEFUN(T,Y,P1,P2...).
h=(tspan(2)-tspan(1))/Nh;
y=y0(:); % cre toujours un vecteur colonne
w=y; u=y.';
tt=linspace(tspan(1),tspan(2),Nh+1);
for t = tt(1:end-1)
 w=w+h*feval(odefun,t,w,varargin{:});
 u = [u; w.'];
end
t=tt;
return
